@@ -1,7 +1,7 @@
 """
 This module implements the Lcapy Matrix class.
 
-Copyright 2019--2021 Michael Hayes, UCECE
+Copyright 2019--2022 Michael Hayes, UCECE
 """
 
 import sympy as sym
@@ -9,6 +9,7 @@ from copy import copy
 from .expr import expr
 from .sym import simplify
 from .printing import pprint, latex, pretty
+from warnings import warn
 
 
 def msympify(expr):
@@ -93,7 +94,8 @@ class Matrix(sym.Matrix):
     def pdb(self):
         """Enter the python debugger."""
 
-        import pdb; pdb.set_trace()
+        import pdb
+        pdb.set_trace()
         return self
 
     def canonical(self):
@@ -104,6 +106,7 @@ class Matrix(sym.Matrix):
     # the following.
 
     def inv(self, method='default'):
+
         Minv = matrix_inverse(sym.Matrix(self), method=method)
 
         return self.__class__(Minv)
@@ -131,12 +134,13 @@ class Matrix(sym.Matrix):
         except:
             pass
 
-        ret = super(Matrix, self).replace(query, value, map, simultaneous, exact)
+        ret = super(Matrix, self).replace(
+            query, value, map, simultaneous, exact)
         return self.__class__(ret)
 
     def rewrite(self, *args, **hints):
 
-        f = lambda x: expr(x).rewrite(*args, **hints).sympy
+        def f(x): return expr(x).rewrite(*args, **hints).sympy
         return self.applyfunc(f)
 
     def simplify(self):
@@ -146,7 +150,7 @@ class Matrix(sym.Matrix):
     def subs(self, *args, **kwargs):
         """Substitute variables in expression, see sympy.subs for usage."""
 
-        f = lambda x: expr(x).subs(*args, **kwargs).sympy
+        def f(x): return expr(x).subs(*args, **kwargs).sympy
         return self.applyfunc(f)
 
     @property
@@ -235,6 +239,12 @@ def matrix_inverse(M, method='default'):
 
     from .config import matrix_inverse_method, matrix_inverse_fallback_method
 
+    N = M.shape[0]
+    if N >= 10:
+        warn("""
+This may take a while...  A symbolic matrix inversion is O(%d^3) for a matrix
+of size %dx%d""" % (N, N, N))
+
     if method == 'default':
         method = matrix_inverse_method
 
@@ -290,4 +300,4 @@ def matrix_inverse(M, method='default'):
         return self.applyfunc(self._typewrap.ZPK)
 
 
-from .expr import Expr, expr
+from .expr import Expr, expr  # nopep8
