@@ -29,7 +29,7 @@ __all__ = ()
 
 module = sys.modules[__name__]
 
-cptaliases = {'E': 'VCVS', 'F': 'CCCS',
+cptaliases = {'F': 'CCCS',
               'G': 'VCCS',  'H': 'CCVS',
               'r': 'Damper', 'm': 'Mass',
               'k': 'Spring'}
@@ -75,9 +75,8 @@ class Cpt(ImmittanceMixin):
                 self.relnodes.append(node)
 
         self._string = string
-        #self.net = string.split(';')[0]
+        # self.net = string.split(';')[0]
         self.args = args
-        self.explicit_args = args
         self.classname = self.__class__.__name__
         self.keyword = keyword
         self.opts = Opts(opts_string)
@@ -85,24 +84,10 @@ class Cpt(ImmittanceMixin):
         self.nosim = 'nosim' in self.opts
 
         # No defined cpt
-        if self.type in ('XX', 'Cable'):
+        if self.type in ('XX', 'Cable') or self.nosim:
             self._cpt = lcapy.oneport.Dummy()
             return
 
-        if ((args == () and not self.type in ('W', 'O', 'P', 'TP', 'TL'))
-            or (self.type in ('F', 'H', 'CCCS', 'CCVS') and len(args) == 1)
-            or (self.type == 'K' and len(args) == 2)):
-            # Default value is the component name
-            value = self.type + self.id
-
-            if False and self.type in ('V', 'I') and keyword[1] == '':
-                # This is too subtle and creates havoc with
-                # the expected behaviour of subs.
-                value = value[0].lower() + value[1:] + '(t)'
-
-            args += (value, )
-            self.args = args
-
         classname = self.classname
         # Handle aliases.
         try:
@@ -140,6 +125,11 @@ class Cpt(ImmittanceMixin):
 
         return str(self)
 
+    def _expand(self):
+        """Make copy of net."""
+
+        return str(self)
+
     def _arg_format(self, value):
         """Place value string inside curly braces if it contains a delimiter."""
 
@@ -153,6 +143,22 @@ class Cpt(ImmittanceMixin):
                 return '{' + string + '}'
         return string
 
+    def annotate(self, *args, **kwargs):
+        """Annotate cpt by adding `kwargs` to opts.
+        For example, `color='blue'` or `'color=blue'`."""
+
+        s = ''
+        for arg in args:
+            s += ',' + arg
+
+        for key, val in kwargs.items():
+            s += ',' + key + '=' + val
+
+        opts = self.opts.copy()
+        opts.add(s)
+
+        return self._netmake(opts=opts)
+
     def _kill(self):
         """Kill sources."""
 
@@ -177,8 +183,9 @@ class Cpt(ImmittanceMixin):
         return self._copy()
 
     def _netsubs(self, node_map=None, zero=False, subs_dict=None):
-        """Create a new net description.  If node_map is not None,
-        rename the nodes.  If zero is True, set args to zero."""
+        """Create a new net description using substitutions in `subs_dict`.
+        If `node_map` is not `None`, rename the nodes.  If `zero` is `True`,
+        set args to zero."""
 
         string = self.defname
         field = 0
@@ -192,23 +199,25 @@ class Cpt(ImmittanceMixin):
                 string += ' ' + self.keyword[1]
                 field += 1
 
-        if subs_dict is None:
-            args = self.explicit_args
-        else:
-            args = self.args
-
         for arg in self.args:
             if zero:
+                # FIXME: zeroing all args doesn't make much sense.
+                # Perhaps only zero first arg?
                 arg = 0
-
-            # Perform substitutions
-            if subs_dict is not None:
+            elif subs_dict is not None:
+                if arg is None:
+                    continue
+                # Perform substitutions
                 arg = str(expr(arg).subs(subs_dict))
 
             string += ' ' + self._arg_format(arg)
             field += 1
             if field == self.keyword[0]:
-                string += self.keyword[1]
+                string += ' ' + self.keyword[1]
+
+        if len(self.args) == 0 and self.keyword[0] == 0:
+            string += ' ' + self.keyword[1]
+
         opts_str = str(self.opts).strip()
         if opts_str != '':
             string += '; ' + opts_str
@@ -245,7 +254,8 @@ class Cpt(ImmittanceMixin):
         parts.extend(fmtargs)
 
         # Insert keyword...
-
+        if self.keyword[0] == 0:
+            parts.append(self.keyword[1])
 
         net = ' '.join(parts)
         opts_str = str(opts).strip()
@@ -274,6 +284,12 @@ class Cpt(ImmittanceMixin):
         name = self.namespace + newtype + self.relname + suffix
         return self._netmake1(name, nodes, args, opts)
 
+    def _netmake_expand(self, name, nodes=None, args=None, opts=None):
+        """This is used for expanding a component into multiple components"""
+
+        name = self.namespace + name + '__' + self.relname
+        return self._netmake1(name, nodes, args, opts)
+
     def _select(self, kind=None):
         """Select domain kind for component."""
         raise ValueError('Component not a source: %s' % self)
@@ -609,39 +625,23 @@ class Cpt(ImmittanceMixin):
 
         return self.dpVoc.time()
 
-    @property
-    def dpYs(self):
-        """Driving-point generalized admittance (s-domain) measured across
-        component in-circuit.  For the admittance of the component in isolation
-        use .Ys"""
-
-        return self.oneport().Ys
-
-    @property
-    def dpZs(self):
-        """Driving-point generalized impedance (s-domain) measured across
-        component in-circuit.  For the impedance of the component in isolation
-        use .Zs"""
-
-        return self.oneport().Zs
-
     @property
     def dpY(self):
         """Driving-point admittance measured across component in-circuit.  For
         the admittance of the component in isolation use .Y"""
 
-        return self.oneport().Y
+        return self.cct.admittance(self.nodenames[1], self.nodenames[0])
 
     @property
     def dpZ(self):
         """Driving-point impedance measured across component in-circuit.  For
         the impedance of the component in isolation use .Z"""
 
-        return self.oneport().Z
+        return self.cct.impedance(self.nodenames[1], self.nodenames[0])
 
-    def dummy_node(self):
+    def _dummy_node(self):
 
-        return '_' + self.cct._make_anon_name('node')
+        return self.cct._dummy_node()
 
     def oneport(self):
         """Create oneport object."""
@@ -695,45 +695,59 @@ class Cpt(ImmittanceMixin):
 
         return cpt in self.connected
 
-    def short(self):
-        """Apply short-circuit across component."""
+    def open_circuit(self):
+        """Apply open-circuit in series with component.  Returns name of
+        open-circuit component."""
+
+        dummy_node = self._dummy_node()
+        net = self._netmake((dummy_node, ) + self.relnodes[1:])
+        self.cct.remove(self.name)
+        self.cct.add(net)
+        self.cct.add('O? %s %s' % (self.relnodes[0], dummy_node))
+        return self.cct.last_added()
+
+    def short_circuit(self):
+        """Apply short-circuit across component.  Returns name of voltage
+        source component used as the short."""
 
         parallel_set = self.in_parallel()
         for cptname in parallel_set:
             cpt = self.cct.elements[cptname]
             if cpt.is_voltage_source:
                 if cpt.value == 0:
-                    warn('Component %s already shorted by %s' % (self.name, cptname))
+                    warn('Component %s already shorted by %s' %
+                         (self.name, cptname))
                 else:
-                    warn('Shorting voltage source %s in parallel with %s' % (cptname, self.name))
+                    warn('Shorting voltage source %s in parallel with %s' %
+                         (cptname, self.name))
             elif cpt.is_current_source:
-                warn('Shorting current source %s in parallel with %s' % (cptname, self.name))
+                warn('Shorting current source %s in parallel with %s' %
+                     (cptname, self.name))
 
-        #self.cct.add('W %s %s' % (self.nodes[0].name, self.nodes[1].name))
-        # Could add zero ohm resistor but then could not determine current
-        # through the short.
+        # Could add wire or zero ohm resistor but then could not
+        # determine current through the short.  So instead add a
+        # voltage source.
         self.cct.add('V? %s %s 0' % (self.nodes[0].name, self.nodes[1].name))
 
-        # Perhaps have option to delete component?
+        return self.cct.last_added()
 
 
 class Invalid(Cpt):
-
-    @property
-    def cpt(self):
-         raise NotImplementedError('Invalid component for circuit analysis: %s' % self)
+    pass
 
 
 class NonLinear(Invalid):
 
     def _stamp(self, mna):
-        raise NotImplementedError('Cannot analyse non-linear component: %s' % self)
+        raise NotImplementedError(
+            'Cannot analyse non-linear component: %s' % self)
 
 
 class TimeVarying(Invalid):
 
     def _stamp(self, mna):
-        raise NotImplementedError('Cannot analyse time-varying component: %s' % self)
+        raise NotImplementedError(
+            'Cannot analyse time-varying component: %s' % self)
 
 
 class Logic(Invalid):
@@ -748,15 +762,6 @@ class Misc(Invalid):
         raise NotImplementedError('Cannot analyse misc component: %s' % self)
 
 
-class Ignored(Cpt):
-
-    ignore = True
-
-    def _stamp(self, mna):
-        # Could print warning
-        pass
-
-
 class Dummy(Cpt):
 
     causal = True
@@ -821,7 +826,7 @@ class RLC(Cpt):
         if self.Voc == 0:
             return self._netmake_variant('Z', args=self.Z(var))
 
-        dummy_node = self.dummy_node()
+        dummy_node = self._dummy_node()
 
         opts = self.opts.copy()
 
@@ -859,7 +864,7 @@ class RC(RLC):
 
     def _noisy(self, T='T'):
 
-        dummy_node = self.dummy_node()
+        dummy_node = self._dummy_node()
 
         opts = self.opts.copy()
 
@@ -926,7 +931,7 @@ class C(RC):
 
     def _r_model(self):
 
-        dummy_node = self.dummy_node()
+        dummy_node = self._dummy_node()
         opts = self.opts.copy()
 
         # Use Thevenin model.  This will require the current through
@@ -1010,6 +1015,97 @@ class VCVS(DependentSource):
         return self._netmake_W(opts=newopts)
 
 
+class E(VCVS):
+    pass
+
+
+class Eopamp(DependentSource):
+    """Operational amplifier"""
+
+    def _expand(self):
+
+        Ad, Ac, Ro = self.args
+
+        Roval = expr(Ro)
+
+        if Roval == 0:
+            onode = self.relnodes[0]
+        else:
+            onode = self._dummy_node()
+
+        vcvs = self._netmake_expand('E',
+                                    nodes=(onode, self.relnodes[1],
+                                           self.relnodes[2], self.relnodes[3]),
+                                    args=(Ad, Ac))
+        if Roval == 0:
+            return vcvs
+
+        rout = self._netmake_expand('R', nodes=(onode, self.relnodes[0]),
+                                    args=(Ro, ))
+
+        return vcvs + '\n' + rout + '\n'
+
+    def _stamp(self, mna):
+        raise RuntimeError('Internal error, component not expanded')
+
+
+class Efdopamp(DependentSource):
+    """Fully differential opamp"""
+
+    def _expand(self):
+
+        Ad, Ac = self.args
+        Ad = '{%s / 2}' % Ad
+
+        opampp = self._netmake_expand('Ep',
+                                      nodes=(self.relnodes[0], self.relnodes[4],
+                                             'opamp',
+                                             self.relnodes[2], self.relnodes[3]),
+                                      args=(Ad, Ac))
+        opampm = self._netmake_expand('Em',
+                                      nodes=(self.relnodes[4], self.relnodes[1],
+                                             'opamp',
+                                             self.relnodes[2], self.relnodes[3]),
+                                      args=(Ad, Ac))
+
+        return opampp + '\n' + opampm + '\n'
+
+    def _stamp(self, mna):
+        raise RuntimeError('Internal error, component not expanded')
+
+
+class Einamp(DependentSource):
+    """Instrumentation amplifier"""
+
+    def _expand(self):
+
+        Ad, Ac, Rf = self.args
+
+        cpts = []
+        node7 = self._dummy_node()
+        node8 = self._dummy_node()
+
+        cpts.append(self._netmake_expand('Ep',
+                                         nodes=(node7, '0', 'opamp',
+                                                self.relnodes[2], self.relnodes[4]),
+                                         args=(Ad, )))
+        cpts.append(self._netmake_expand('Em',
+                                         nodes=(node8, '0', 'opamp',
+                                                self.relnodes[3], self.relnodes[5]),
+                                         args=(Ad, )))
+        cpts.append(self._netmake_expand('Ed',
+                                         nodes=(self.relnodes[0], self.relnodes[1], 'opamp',
+                                                node7, node8), args=('1', Ac)))
+        cpts.append(self._netmake_expand('Rfp',
+                                         nodes=(self.relnodes[4], node7), args=(Rf, )))
+        cpts.append(self._netmake_expand('Rfm',
+                                         nodes=(self.relnodes[5], node8), args=(Rf, )))
+        return '\n'.join(cpts)
+
+    def _stamp(self, mna):
+        raise RuntimeError('Internal error, component not expanded')
+
+
 class CCCS(DependentSource):
     """CCCS"""
 
@@ -1071,7 +1167,7 @@ class GY(Dummy):
     def _stamp(self, mna):
 
         n1, n2, n3, n4 = mna._cpt_node_indexes(self)
-        m1 = self.mna._branch_index(self.defname + 'X')
+        m1 = mna._branch_index(self.defname + 'X')
         m2 = mna._cpt_branch_index(self)
 
         # m1 is the input branch
@@ -1106,14 +1202,14 @@ class GY(Dummy):
 
 
 class TVtriode(Dummy):
-    """Triode"""    
+    """Triode"""
 
     need_branch_current = True
     need_extra_branch_current = True
 
     def _stamp(self, cct):
-        
-        n1, n2, n3= self.node_indexes
+
+        n1, n2, n3 = self.node_indexes
         m1 = self.cct._branch_index(self.defname + 'X')
         m2 = self.branch_index
 
@@ -1127,10 +1223,10 @@ class TVtriode(Dummy):
 
         # V2 = -I1 Z2     V1 = I2 Z1
         # where V2 = V[n1] - V[n2] and V1 = V[n3] - V[n4]
-        
-        Z1 = ConstantDomainExpression(self.args[0]).expr                    
+
+        Z1 = ConstantDomainExpression(self.args[0]).expr
         Z2 = Z1
-        
+
         if n1 >= 0:
             cct._B[n1, m2] += 1
             cct._C[m1, n1] += 1
@@ -1139,7 +1235,7 @@ class TVtriode(Dummy):
             cct._C[m1, n2] -= 1
         if n3 >= 0:
             cct._B[n3, m1] += 1
-            cct._C[m2, n3] += 1 
+            cct._C[m2, n3] += 1
 
         cct._D[m1, m1] += Z2
         cct._D[m2, m2] -= Z1
@@ -1218,9 +1314,9 @@ class K(Dummy):
 
         self.Lname1 = args[0]
         self.Lname2 = args[1]
-        super (K, self).__init__(cct, namespace, defname, name,
-                                 cpt_type, cpt_id, string,
-                                 opts_string, nodes, keyword, *args)
+        super(K, self).__init__(cct, namespace, defname, name,
+                                cpt_type, cpt_id, string,
+                                opts_string, nodes, keyword, *args)
 
     def _stamp(self, mna):
         from .sym import ssym
@@ -1260,7 +1356,7 @@ class L(RLC):
 
     def _r_model(self):
 
-        dummy_node = self.dummy_node()
+        dummy_node = self._dummy_node()
         opts = self.opts.copy()
 
         # Use Thevenin model.  This will require the current through
@@ -1366,6 +1462,7 @@ class R(RC):
     def _r_model(self):
         return self._copy()
 
+
 class NR(R):
 
     add_series = True
@@ -1510,7 +1607,8 @@ class TFtap(Cpt):
     """Tapped transformer"""
 
     def _stamp(self, mna):
-        raise NotImplementedError('Cannot analyse tapped transformer %s' % self)
+        raise NotImplementedError(
+            'Cannot analyse tapped transformer %s' % self)
 
 
 class TL(Cpt):
@@ -1535,6 +1633,7 @@ class TL(Cpt):
         A21 = cpt.A21.sympy
         A22 = cpt.A22.sympy
 
+        # This stamp is the same as an A twoport.
         if n1 >= 0:
             if n3 >= 0:
                 mna._G[n1, n3] += A21
@@ -1570,12 +1669,15 @@ class TL(Cpt):
         mna._D[m, m] += A12
 
 
-class Cable(Ignored):
+class Cable(Cpt):
     """Cable"""
 
     equipotential_nodes = (('in+', 'out+'), ('in-', 'out-'), ('in', 'out'),
                            ('ignd', 'ognd', 'b', 't'), ('mid', 'out'))
 
+    def _stamp(self, mna):
+        pass
+
 
 class TP(Misc):
     """Two port"""
@@ -1646,7 +1748,7 @@ class TPB(TPA):
         if self.cpt.V2b != 0 or self.cpt.I2b != 0:
             raise ValueError('Sources not supported yet for %s' % self)
 
-        super (TPB, self)._stamp(mna)
+        super(TPB, self)._stamp(mna)
 
 
 class TPG(TPA):
@@ -1659,7 +1761,7 @@ class TPG(TPA):
         if self.cpt.I1g != 0 or self.cpt.V2g != 0:
             raise ValueError('Sources not supported yet for %s' % self)
 
-        super (TPG, self)._stamp(mna)
+        super(TPG, self)._stamp(mna)
 
 
 class TPH(TPA):
@@ -1672,7 +1774,7 @@ class TPH(TPA):
         if self.cpt.V1h != 0 or self.cpt.I2h != 0:
             raise ValueError('Sources not supported yet for %s' % self)
 
-        super (TPH, self)._stamp(mna)
+        super(TPH, self)._stamp(mna)
 
 
 class TPY(TPCpt):
@@ -1734,7 +1836,7 @@ class TPZ(TPY):
         if self.cpt.V1z != 0 or self.cpt.V2z != 0:
             raise ValueError('Sources not supported yet for %s' % self)
 
-        super (TPZ, self)._stamp(mna)
+        super(TPZ, self)._stamp(mna)
 
 
 class TR(Dummy):
@@ -1808,11 +1910,13 @@ class W(Dummy):
 
     @property
     def I(self):
-        raise ValueError('Cannot determine current through wire, use a 0 V voltage source')
+        raise ValueError(
+            'Cannot determine current through wire, use a 0 V voltage source')
 
     @property
     def i(self):
-        raise ValueError('Cannot determine current through wire, use a 0 V voltage source')
+        raise ValueError(
+            'Cannot determine current through wire, use a 0 V voltage source')
 
 
 class XT(Misc):
@@ -1837,6 +1941,7 @@ class Z(RC):
 
 classes = {}
 
+
 def defcpt(name, base, docstring):
 
     if isinstance(base, str):
@@ -1847,14 +1952,14 @@ def defcpt(name, base, docstring):
     classes[name] = newclass
 
 
-def make(classname, parent, name, cpt_type, cpt_id,
-         string, opts_string, nodes, *args):
+def make(classname, parent, namespace, defname, name, cpt_type, cpt_id,
+         string, opts_string, nodes, keyword, *args):
 
     # Create instance of component object
     newclass = classes[classname]
 
-    cpt = newclass(parent, name, cpt_type, cpt_id, string, opts_string,
-                   nodes, *args)
+    cpt = newclass(parent, namespace, defname, name, cpt_type, cpt_id, string,
+                   opts_string, nodes, keyword, *args)
 
     return cpt
 
@@ -1874,9 +1979,6 @@ defcpt('Dschottky', 'D', 'Schottky diode')
 defcpt('Dtunnel', 'D', 'Tunnel diode')
 defcpt('Dzener', 'D', 'Zener diode')
 
-defcpt('E', VCVS, 'VCVS')
-defcpt('Eopamp', VCVS, 'Opamp')
-defcpt('Efdopamp', VCVS, 'Fully differential opamp')
 defcpt('Eamp', VCVS, 'Amplifier')
 
 defcpt('F', CCCS, 'CCCS')
@@ -1972,6 +2074,7 @@ defcpt('k', C, 'Spring')
 defcpt('r', R, 'Damper')
 
 # Append classes defined in this module but not imported.
-clsmembers = inspect.getmembers(module, lambda member: inspect.isclass(member) and member.__module__ == __name__)
+clsmembers = inspect.getmembers(module, lambda member: inspect.isclass(
+    member) and member.__module__ == __name__)
 for name, cls in clsmembers:
     classes[name] = cls
