@@ -32,7 +32,7 @@ class Network(object):
     # False if initial conditions are not specified.
     has_ic = None
 
-    netname = ''
+    cpt_type = ''
     netkeyword = ''
     kwargs = {}
 
@@ -83,7 +83,8 @@ class Network(object):
         for key, val in self.kwargs.items():
             parts.append("%s='%s'" % (key, val))
 
-        argsrepr = ', '.join([pretty1(arg, **kwargs) for arg in self.args] + parts)
+        argsrepr = ', '.join([pretty1(arg, **kwargs)
+                             for arg in self.args] + parts)
         return '%s(%s)' % (self.__class__.__name__, argsrepr)
 
     def latex(self, **kwargs):
@@ -122,7 +123,7 @@ class Network(object):
         # Hack, create ground reference.
         self._add('W %d 0' % (self._node - 1))
 
-    def _net_make(self, netlist, n1=None, n2=None, dir='right'):
+    def _net_make(self, netlistmaker, n1=None, n2=None, dir='right'):
 
         net = self
         if n2 == None:
@@ -130,18 +131,16 @@ class Network(object):
         if n1 == None:
             n1 = net._node
 
-        netname = net.__class__.__name__ if net.netname == '' else net.netname
+        cpt_type = net.__class__.__name__ if net.cpt_type == '' else net.cpt_type
 
         opts_str = self._opts_str(dir)
-        netid = netlist._make_id(netname)
+        name = netlistmaker._make_name(cpt_type, self.args)
         if net.netkeyword != '':
-            return '%s%s %s %s %s %s; %s' % (netname, netid,
-                                             n1, n2,
-                                             net.netkeyword,
-                                             netlist._netargs(net), opts_str)
+            return '%s %s %s %s %s; %s' % (name, n1, n2, net.netkeyword,
+                                           netlistmaker._netargs(net), opts_str)
         else:
-            return '%s%s %s %s %s; %s' % (netname, netid,
-                                          n1, n2, netlist._netargs(net), opts_str)
+            return '%s %s %s %s; %s' % (name, n1, n2,
+                                        netlistmaker._netargs(net), opts_str)
 
     @property
     def _depths(self):
@@ -176,7 +175,8 @@ class Network(object):
     def pdb(self):
         """Enter the python debugger."""
 
-        import pdb; pdb.set_trace()
+        import pdb
+        pdb.set_trace()
         return self
 
     def sch(self, layout='horizontal', evalf=False):
@@ -298,7 +298,7 @@ class Network(object):
 
     @property
     def params(self):
-        """Return list of symbols used as arguments in the circuit."""
+        """Return list of symbols used as arguments in the network."""
 
         # This would be faster to determine directly from AST.
         return self.cct.params
@@ -309,15 +309,6 @@ class Network(object):
 
         return self.cct.symbols
 
-    @property
-    def all_symbols(self):
-        """Return dictionary of symbols defined in the network and global
-        symbols."""
-
-        symbols = self.symbols
-        symbols.update(state.global_context.symbols)
-        return symbols
-
     def transform(self, form='cauerI'):
         """Transform the network impedance into an alternative form.  The
         transformation is performed using network synthesis of the
