@@ -15,7 +15,7 @@ currents, respectively, to model transient responses.
 One-ports can either be connected in series (+) or parallel (|) to
 create a new one-port.
 
-Copyright 2014--2021 Michael Hayes, UCECE
+Copyright 2014--2022 Michael Hayes, UCECE
 """
 
 from __future__ import division
@@ -38,6 +38,7 @@ __all__ = ('V', 'I', 'v', 'i', 'R', 'NR', 'L', 'C', 'G', 'Y', 'Z',
            'Par', 'Ser', 'Xtal', 'FerriteBead', 'CPE', 'series', 'parallel',
            'ladder')
 
+
 def _check_oneport_args(args):
 
     for arg1 in args:
@@ -459,7 +460,7 @@ class ParSer(OnePort):
                 # The currents should be the same!
                 if arg1.i0 != arg2.i0 or arg1.has_ic != arg2.has_ic:
                     raise ValueError('Series inductors with different'
-                          ' initial currents!')
+                                     ' initial currents!')
                 i0 = arg1.i0 if arg1.has_ic else None
                 return L(arg1.L + arg2.L, i0)
             if isinstance(arg1, G):
@@ -483,7 +484,7 @@ class ParSer(OnePort):
                 # The voltages should be the same!
                 if arg1.v0 != arg2.v0 or arg1.has_ic != arg2.has_ic:
                     raise ValueError('Parallel capacitors with different'
-                          ' initial voltages!')
+                                     ' initial voltages!')
                 v0 = arg1.v0 if arg1.has_ic else None
                 return C(arg1.C + arg2.C, v0)
             if isinstance(arg1, R):
@@ -615,11 +616,12 @@ class Par(ParSer):
                     raise ValueError('Voltage sources connected in parallel'
                                      ' %s and %s' % (arg1, arg2))
                 elif isinstance(arg1, V):
-                    print('Warn: redundant component %s in parallel with voltage source %s' % (arg2, arg1))
+                    print('Warn: redundant component %s in parallel with voltage source %s' % (
+                        arg2, arg1))
 
                 elif isinstance(arg2, V):
-                    print('Warn: redundant component %s in parallel with voltage source %s' % (arg1, arg2))
-
+                    print('Warn: redundant component %s in parallel with voltage source %s' % (
+                        arg1, arg2))
 
     @property
     def width(self):
@@ -644,7 +646,7 @@ class Par(ParSer):
         s = []
         if n1 is None:
             n1 = netlist._node
-        n3, n4 =  netlist._node, netlist._node
+        n3, n4 = netlist._node, netlist._node
 
         H = [(arg.height + self.hsep) * 0.5 for arg in self.args]
 
@@ -672,7 +674,7 @@ class Par(ParSer):
             else:
                 sep = H[N // 2 - n] + H[N // 2 - 1 - n]
 
-            nc, nd =  netlist._node, netlist._node
+            nc, nd = netlist._node, netlist._node
             s.append('W %s %s; %s=%s' % (na, nc, updir, sep))
             s.append('W %s %s; %s=%s' % (nb, nd, updir, sep))
             s.append(self.args[N // 2 - 1 - n]._net_make(netlist, nc, nd, dir))
@@ -688,10 +690,11 @@ class Par(ParSer):
             else:
                 sep = H[(N + 1) // 2 + n] + H[(N + 1) // 2 - 1 + n]
 
-            nc, nd =  netlist._node, netlist._node
+            nc, nd = netlist._node, netlist._node
             s.append('W %s %s; %s=%s' % (na, nc, downdir, sep))
             s.append('W %s %s; %s=%s' % (nb, nd, downdir, sep))
-            s.append(self.args[(N + 1) // 2 + n]._net_make(netlist, nc, nd, dir))
+            s.append(self.args[(N + 1) // 2 +
+                     n]._net_make(netlist, nc, nd, dir))
             na, nb = nc, nd
 
         if n2 is None:
@@ -748,10 +751,12 @@ class Ser(ParSer):
                     raise ValueError('Current sources connected in series'
                                      ' %s and %s' % (arg1, arg2))
                 elif isinstance(arg1, I):
-                    print('Warn: redundant component %s in series with current source %s' % (arg2, arg1))
+                    print(
+                        'Warn: redundant component %s in series with current source %s' % (arg2, arg1))
 
                 elif isinstance(arg2, I):
-                    print('Warn: redundant component %s in series with current source %s' % (arg1, arg2))
+                    print(
+                        'Warn: redundant component %s in series with current source %s' % (arg1, arg2))
 
     @property
     def height(self):
@@ -1018,7 +1023,7 @@ class Z(OnePort):
 class VoltageSourceBase(OnePort):
 
     is_voltage_source = True
-    netname = 'V'
+    cpt_type = 'V'
     is_noisy = False
 
     def v_equation(self, i, kind='t'):
@@ -1059,7 +1064,8 @@ class Vstep(VoltageSourceBase):
         self.kwargs = kwargs
         self.args = (v, )
         v = cexpr(v)
-        self._Voc = SuperpositionVoltage(TimeDomainExpression(v) * Heaviside(t))
+        self._Voc = SuperpositionVoltage(
+            TimeDomainExpression(v) * Heaviside(t))
         self.v0 = v
 
 
@@ -1150,7 +1156,7 @@ class v(VoltageSourceBase):
 class CurrentSourceBase(OnePort):
 
     is_current_source = True
-    netname = 'I'
+    cpt_type = 'I'
     is_noisy = False
 
     @property
@@ -1206,7 +1212,8 @@ class Istep(CurrentSourceBase):
         self.kwargs = kwargs
         self.args = (Ival, )
         Ival = cexpr(Ival)
-        self._Isc = SuperpositionCurrent(TimeDomainExpression(Ival) * Heaviside(t))
+        self._Isc = SuperpositionCurrent(
+            TimeDomainExpression(Ival) * Heaviside(t))
         self.i0 = Ival
 
 
@@ -1451,7 +1458,7 @@ class K(Dummy):
 
     def __init__(self, L1, L2, K, **kwargs):
 
-        if K is ksym or (isinstance(K, Expr) and K.var is ksym) :
+        if K is ksym or (isinstance(K, Expr) and K.var is ksym):
             warn("""
 Coupling coefficient %s is the discrete Fourier domain variable.
 You can override it using %s = symbol('%s', force=True).""" % (K, K, K))
@@ -1549,18 +1556,18 @@ def ladder(*args, **kwargs):
     elif len(args) == 1:
         return args[0]
     elif start_series:
-        return series(args[0], ladder(*args[1:], start_series = not start_series))
+        return series(args[0], ladder(*args[1:], start_series=not start_series))
     else:
-        return parallel(args[0], ladder(*args[1:], start_series = not start_series))
+        return parallel(args[0], ladder(*args[1:], start_series=not start_series))
 
 
 # Imports at end to circumvent circular dependencies
-from .expr import Expr, expr
-from .cexpr import cexpr
-from .sexpr import LaplaceDomainExpression
-from .texpr import TimeDomainExpression
-from .phasor import phasor
-from .noiseomegaexpr import AngularFourierNoiseDomainCurrent, AngularFourierNoiseDomainVoltage
-from .superpositionvoltage import SuperpositionVoltage
-from .superpositioncurrent import SuperpositionCurrent
-from .twoport import Ladder, LSection, TSection
+from .twoport import Ladder, LSection, TSection  # nopep8
+from .superpositioncurrent import SuperpositionCurrent  # nopep8
+from .superpositionvoltage import SuperpositionVoltage  # nopep8
+from .noiseomegaexpr import AngularFourierNoiseDomainCurrent, AngularFourierNoiseDomainVoltage  # nopep8
+from .phasor import phasor  # nopep8
+from .texpr import TimeDomainExpression  # nopep8
+from .sexpr import LaplaceDomainExpression  # nopep8
+from .cexpr import cexpr  # nopep8
+from .expr import Expr, expr  # nopep8
