@@ -1,7 +1,7 @@
 """This module performs parsing of SPICE-like netlists.  It uses a
 custom parser rather than lex/yacc to give better error messages.
 
-Copyright 2015--2020 Michael Hayes, UCECE
+Copyright 2015--2022 Michael Hayes, UCECE
 
 """
 
@@ -10,6 +10,19 @@ import re
 # Could use a script to generate parser and parsing tables if speed
 # was important.
 
+# Each line of a netlist (called net here) has a name followed by a
+# number of required parameters (params), a number of optional
+# parameters, an optional semicolon, and optional comma separated
+# key-value pairs.
+#
+# Each param can be a node, keyword, name, or value.
+#
+# Here's an example: I1 4 5 {Piecewise((V/L, t >= 0))}; right
+# The name is I1; 4, 5 are nodes; the expression is brackets is a value.
+#
+# The name or value params are referred to as args.
+
+
 def split(s, delimiters):
     """Split string by specified delimiters but not if a delimiter is
     within curly brackets {} or ""."""
@@ -25,7 +38,7 @@ def split(s, delimiters):
             current = []
         else:
             if c == close_bracket:
-                close_bracket = bracket_stack.pop()                
+                close_bracket = bracket_stack.pop()
             elif c == '{':
                 bracket_stack.append(close_bracket)
                 close_bracket = '}'
@@ -38,10 +51,10 @@ def split(s, delimiters):
     return parts
 
 
-class Param(object):
+class ParamDef:
 
     def __init__(self, name, base, comment):
-        
+
         self.name = name
         self.base = base
         self.comment = comment
@@ -54,62 +67,170 @@ class Param(object):
         return self.baseclass.is_valid(string)
 
 
-class Rule(object):
+class Param:
+
+    def __init__(self, paramstr, paramdict):
+
+        self.optional = paramstr[0] == '['
+
+        if self.optional:
+            paramstr = paramstr[1:-1]
+
+        parts = paramstr.split('=')
+        self.name = parts[0]
+
+        if self.name not in paramdict:
+            raise ValueError('Unknown parameter ' + self.name)
+        self.kind = paramdict[self.name].base
+
+        if len(parts) == 1:
+            self.default = None
+        else:
+            self.default = parts[1]
+
+        self.lowercase_name = self.name.lower()
+
+
+class Arg:
+
+    def __init__(self, param, name):
+        """Set default value."""
+
+        self.name = param.name
+        self.assigned = False
+
+        if param.default == 'name':
+            default = name
+        else:
+            default = param.default
+        self.value = default
+
+    def assign(self, value):
+
+        if self.assigned:
+            raise ValueError('Param %s already assigned' % self.name)
+
+        if value[0] in '{"':
+            value = value[1:-1]
+        self.value = value
+        self.assigned = True
+
+
+class Args(list):
+
+    def index(self, name):
+
+        name = name.lower()
+        for m, arg in enumerate(self):
+            if arg.name.lower() == name:
+                return m
+        return -1
+
+
+class Rule:
+
+    def __init__(self, cpt_type, classname, fields, params, comment, pos):
 
-    def __init__(self, cpt_type, classname, params, comment, pos):
-        
         self.type = cpt_type
         self.classname = classname
+        self.fields = fields
         self.params = params
         self.comment = comment
         self.pos = pos
 
     def __repr__(self):
 
-        return self.type + 'name ' + ' '.join(self.params)
+        return self.type + 'name ' + ' '.join(self.fields[1:])
 
     def syntax_error(self, error, string):
 
-        raise ValueError('Syntax error: %s when parsing %s\nExpected format: %s' % (error, string, repr(self)))        
+        raise ValueError('Syntax error: %s when parsing %s\nExpected format: %s' % (
+            error, string, repr(self)))
 
-    def process(self, paramdict, string, fields, name, namespace):
+    def extract_nodes(self, string, fields, name, namespace):
 
-        params = self.params
-        if len(fields) > len(params):
+        ruleparams = self.params
+        nodes = []
+
+        for m, ruleparam in enumerate(ruleparams):
+
+            if ruleparam.kind not in ('pin', 'node'):
+                continue
+
+            if m >= len(fields):
+                self.syntax_error('Missing node %s' % ruleparam.name, string)
+
+            field = fields[m]
+            if field[0] == '.':
+                # Note, name contains namespace
+                field = name + field
+            else:
+                field = namespace + field
+            nodes.append(field)
+
+        return tuple(nodes)
+
+    def extract_args(self, string, fields, name, namespace, default_value):
+
+        args = Args()
+        m2 = 0
+        for m, ruleparam in enumerate(self.params):
+
+            if ruleparam.kind not in ('name', 'value'):
+                m2 = m + 1
+                continue
+
+            if m >= len(fields):
+                if not ruleparam.optional:
+                    self.syntax_error('Missing arg %s' % ruleparam, string)
+
+            args.append(Arg(ruleparam, default_value))
+
+        # Handle unnamed params
+        m = 0
+        for field in fields[m2:]:
+            parts = split(field, '=')
+            if len(parts) > 1:
+                break
+            args[m].assign(field)
+            m += 1
+
+        # Handle named params
+        for field in fields[m2 + m:]:
+            parts = split(field, '=')
+            if len(parts) < 2:
+                self.syntax_error(
+                    'Cannot have value %s after named param' % field, string)
+            parts = split(field, '=')
+
+            index = args.index(parts[0])
+            if index < 0:
+                self.syntax_error('Unknown param ' + parts[0], string)
+
+            args[index].assign(parts[1])
+
+        args = [arg.value for arg in args]
+
+        return args
+
+    def process(self, string, fields, name, namespace, default_value):
+
+        ruleparams = self.params
+        if len(fields) > len(ruleparams):
             extra = ''
             if '(' in string:
                 extra = ' (perhaps enclose expressions with parentheses in {})'
             self.syntax_error('Too many args' + extra, string)
 
-        nodes = []
-        args = []
-        for m, param in enumerate(params):
+        nodes = self.extract_nodes(string, fields, name, namespace)
 
-            if m >= len(fields):
-                # Optional argument
-                if param[0] == '[':
-                    break
-                self.syntax_error('Missing arg %s' % param, string)
+        args = self.extract_args(string, fields, name,
+                                 namespace, default_value)
 
-            if param[0] == '[':
-                param = param[1:-1]
-
-            field = fields[m]
-
-            if paramdict[param].base in ('pin', 'node'):
-                if field[0] == '.':
-                    # Note, name contains namespace
-                    field = name + field
-                else:
-                    field = namespace + field
-                nodes.append(field)
-            elif paramdict[param].base != 'keyword':
-                args.append(field)
-
-        return tuple(nodes), args
+        return nodes, args
 
 
-class Parser(object):
+class Parser:
 
     def __init__(self, cpts, grammar, allow_anon=False):
         """cpts is a module containing a class for each component
@@ -128,7 +249,7 @@ class Parser(object):
         self.cpts = cpts
         self.paramdict = {}
         self.ruledict = {}
-        
+
         for param in params.split('\n'):
             self._add_param(param)
 
@@ -151,8 +272,8 @@ class Parser(object):
         fields = fields[1].split(';', 1)
         parambase = fields[0].strip()
         comment = fields[1].strip()
-        
-        self.paramdict[paramname] = Param(paramname, parambase, comment)
+
+        self.paramdict[paramname] = ParamDef(paramname, parambase, comment)
 
     def _add_rule(self, string):
 
@@ -164,26 +285,25 @@ class Parser(object):
         fields = fields[1].split(';', 1)
         string = fields[0].strip()
         comment = fields[1].strip()
-        
+
         fields = string.split(' ')
-        params = fields[1:]
 
         # Skip the name part in the rule, e.g., only consider D from Dname.
         cpt_type = fields[0][0:-4]
 
         pos = None
-        for m, param in enumerate(params):
-            if param[0] == '[':
-                param = param[1:-1]
-            if param not in self.paramdict:
-                raise ValueError('Unknown parameter %s for %s' % (param, string))
-            if pos is None and self.paramdict[param].base == 'keyword':
+        params = []
+        for m, paramstr in enumerate(fields[1:]):
+
+            param = Param(paramstr, self.paramdict)
+            params.append(param)
+            if pos is None and param.kind == 'keyword':
                 pos = m
 
         if cpt_type not in self.ruledict:
             self.ruledict[cpt_type] = ()
-        self.ruledict[cpt_type] += (Rule(cpt_type, cpt_classname,
-                                        params, comment, pos), )
+        self.ruledict[cpt_type] += (Rule(cpt_type, cpt_classname, fields,
+                                         params, comment, pos), )
 
     def parse(self, string, namespace='', parent=None):
         """Parse string and create object"""
@@ -193,9 +313,9 @@ class Parser(object):
         if net == '':
             directive = True
         elif net[0] in self.comments:
-            directive = True            
+            directive = True
         elif net[0] == ';':
-            directive = True                        
+            directive = True
         elif net[0] == '.':
             directive = True
 
@@ -203,27 +323,23 @@ class Parser(object):
             cpt_type = 'XX'
             cpt_id = ''
             name = 'XX'
-            name += parent._make_anon_netid(cpt_type)
+            name += parent._make_anon_cpt_id(cpt_type)
             defname = namespace + cpt_type + cpt_id
 
             if string.startswith(';') and not string.startswith(';;'):
                 opts_string = string[1:]
             else:
-                opts_string = ''                
-                
+                opts_string = ''
+
             return self.cpts.make('XX', parent, '', defname, name,
-                                  cpt_type, cpt_id, string, opts_string, (), '')
+                                  cpt_type, cpt_id, string, opts_string, (), '',
+                                  Args())
 
         net = namespace + net
         parts = net.split(';', 1)
-        
+
         fields = split(parts[0], self.delimiters)
 
-        # Strip {} and "".
-        for m, field in enumerate(fields):
-            if field[0] in '{"':
-                fields[m] = fields[m][1:-1]
-        
         name = fields.pop(0)
         parts = name.split('.')
         namespace = ''
@@ -233,7 +349,8 @@ class Parser(object):
 
         match = self.cpt_pattern.match(name)
         if match is None:
-            raise ValueError('Unknown component %s while parsing "%s"' % (name, net))
+            raise ValueError(
+                'Unknown component %s while parsing "%s"' % (name, net))
 
         groups = match.groups()
         cpt_type, cpt_id = groups[0], groups[1]
@@ -251,29 +368,29 @@ class Parser(object):
             pos = rule1.pos
             if pos is None:
                 continue
-            if len(fields) > pos and fields[pos].lower() == rule1.params[pos].lower():
+            if len(fields) > pos and fields[pos].lower() == rule1.params[pos].lowercase_name:
                 rule = rule1
-                keyword = rule1.params[pos]
+                keyword = rule1.params[pos].name
                 break
 
         defname = namespace + cpt_type + cpt_id
         name = defname
         if (cpt_id == '' and parent is not None
-            and (cpt_type in ('A', 'W', 'O', 'P')) or self.allow_anon):
-            name += parent._make_anon_netid(cpt_type)
+                and (cpt_type in ('A', 'W', 'O', 'P')) or self.allow_anon):
+            name += parent._make_anon_cpt_id(cpt_type)
         elif cpt_id == '?':
             # Automatically name cpts to ensure they are unique
-            name = name[:-1] + parent._make_anon_netid(cpt_type)
+            name = name[:-1] + parent._make_anon_cpt_id(cpt_type)
 
-        nodes, args = rule.process(self.paramdict, net, fields, name, 
-                                   namespace)
+        default_value = cpt_type + cpt_id
+        nodes, args = rule.process(net, fields, name, namespace, default_value)
 
         parts = net.split(';', 1)
-        opts_string = parts[1].strip() if len(parts) > 1 else '' 
+        opts_string = parts[1].strip() if len(parts) > 1 else ''
 
         keyword = (pos, keyword)
 
-        # self.cpts is either the mnacpts or schematic module
+        # self.cpts is either the mnacpts or schemcpts module
         return self.cpts.make(rule.classname, parent, namespace,
                               defname, name, cpt_type, cpt_id, net,
                               opts_string, tuple(nodes), keyword,
