@@ -96,7 +96,7 @@ def plot_deltas(ax, t, deltas, var, plot_type='real', color='k'):
         sy = ymax
 
         ax.arrow(t0, 0, 0, y1, fc=color, ec=color,
-                 width = 0.025 * st, head_width=0.1 * st,
+                 width=0.025 * st, head_width=0.1 * st,
                  head_length=0.1 * sy, overhang=0,
                  length_includes_head=True, clip_on=False)
 
@@ -129,7 +129,8 @@ def plot_pole_zero(obj, **kwargs):
     a = np.hstack((p, z))
 
     if unitcircle:
-        ax.add_artist(Circle((0, 0), 1, color='blue', linestyle='--', fill=False))
+        ax.add_artist(Circle((0, 0), 1, color='blue',
+                      linestyle='--', fill=False))
 
     x_min = a.real.min()
     x_max = a.real.max()
@@ -209,12 +210,12 @@ def plot_pole_zero(obj, **kwargs):
 
 
 def plotit(ax, obj, f, V, plot_type=None, deltas=None, log_magnitude=False,
-           log_frequency=False, norm=False, dbmin=-120, **kwargs):
+           log_frequency=False, norm=False, dbmin=-120, unwrap=False, **kwargs):
 
-    plots = {(True, True) : ax.loglog,
-             (True, False) : ax.semilogy,
-             (False, True) : ax.semilogx,
-             (False, False) : ax.plot}
+    plots = {(True, True): ax.loglog,
+             (True, False): ax.semilogy,
+             (False, True): ax.semilogx,
+             (False, False): ax.plot}
 
     label = ''
     if hasattr(obj, 'quantity_label'):
@@ -242,10 +243,15 @@ def plotit(ax, obj, f, V, plot_type=None, deltas=None, log_magnitude=False,
         units = 'dB'
     elif plot_type == 'radians':
         V = np.angle(V)
+        if unwrap:
+            V = np.unwrap(V)
         part = 'phase'
         units = 'radians'
     elif plot_type == 'degrees':
-        V = np.degrees(np.angle(V))
+        V = np.angle(V)
+        if unwrap:
+            V = np.unwrap(V)
+        V = np.degrees(V)
         part = 'phase'
         units = 'degrees'
 
@@ -303,7 +309,8 @@ def plot_frequency(obj, f, plot_type=None, **kwargs):
     norm = kwargs.pop('norm', False)
     npoints = kwargs.pop('npoints', 400)
     log_magnitude = kwargs.pop('log_magnitude', False)
-    log_frequency = kwargs.pop('log_frequency', False) or kwargs.pop('log_scale', False)
+    log_frequency = kwargs.pop(
+        'log_frequency', False) or kwargs.pop('log_scale', False)
     if kwargs.pop('loglog', False):
         log_magnitude = True
         log_frequency = True
@@ -313,6 +320,7 @@ def plot_frequency(obj, f, plot_type=None, **kwargs):
     nyticks = kwargs.pop('nyticks', None)
     color2 = kwargs.pop('color2', None)
     linestyle2 = kwargs.pop('linestyle2', '--')
+    unwrap = kwargs.pop('unwrap', False)
 
     # FIXME, determine useful frequency range...
     if f is None:
@@ -339,12 +347,14 @@ def plot_frequency(obj, f, plot_type=None, **kwargs):
 
     V = obj.evaluate(f)
 
-    types = ['dB-phase', 'dB-radians', 'dB-phase-degrees', 'dB-degrees',
-             'mag-phase', 'magnitude-phase', 'mag-phase-degrees','magnitude-phase-degrees',
-             'real-imag', 'mag', 'magnitude', 'phase', 'radians', 'phase-degrees',
-             'degrees', 'real', 'imag', 'dB', 'abs']
+    types = ['dB-phase', 'dB-radians', 'dB-phase-degrees',
+             'dB-degrees', 'mag-phase', 'magnitude-phase',
+             'mag-phase-degrees', 'magnitude-phase-degrees',
+             'real-imag', 'mag', 'magnitude', 'phase', 'radians',
+             'phase-degrees', 'degrees', 'real', 'imag', 'dB', 'abs']
     if plot_type is not None and plot_type not in types:
-        raise ValueError('Unknown plot type %s, expecting: %s ' % (plot_type, ', '.join(types)))
+        raise ValueError('Unknown plot type %s, expecting: %s ' %
+                         (plot_type, ', '.join(types)))
 
     if not V.dtype == complex:
         if plot_type is None:
@@ -362,11 +372,11 @@ def plot_frequency(obj, f, plot_type=None, **kwargs):
         plot1_type = 'dB'
         plot2_type = 'degrees'
     elif plot_type in ('mag_phase', 'magnitude_phase',
-                       'mag-phase','magnitude-phase'):
+                       'mag-phase', 'magnitude-phase'):
         plot1_type = 'magnitude'
         plot2_type = 'radians'
     elif plot_type in ('mag_phase_degrees', 'magnitude_phase_degrees',
-                       'mag-phase-degrees','magnitude-phase-degrees'):
+                       'mag-phase-degrees', 'magnitude-phase-degrees'):
         plot1_type = 'magnitude'
         plot2_type = 'degrees'
     elif plot_type in ('real_imag', 'real-imag'):
@@ -402,8 +412,10 @@ def plot_frequency(obj, f, plot_type=None, **kwargs):
     if label is None:
         label = plot1_type
 
-    lines = plotit(ax, obj, f, V, plot1_type, deltas, log_frequency=log_frequency,
-                   log_magnitude=log_magnitude, norm=norm, label=label, dbmin=dbmin, **kwargs)
+    lines = plotit(ax, obj, f, V, plot1_type, deltas,
+                   log_frequency=log_frequency,
+                   log_magnitude=log_magnitude, norm=norm,
+                   label=label, dbmin=dbmin, unwrap=unwrap, **kwargs)
 
     if plot2_type is None:
         return ax
@@ -416,7 +428,8 @@ def plot_frequency(obj, f, plot_type=None, **kwargs):
         kwargs2.pop(key, None)
 
     # Dummy plot to add label to legend.
-    ax.plot([], [], label=plot2_type, color=color2, linestyle=linestyle2, **kwargs2)
+    ax.plot([], [], label=plot2_type, color=color2,
+            linestyle=linestyle2, **kwargs2)
 
     ax2 = ax.twinx()
     kwargs['axes'] = ax2
@@ -424,11 +437,11 @@ def plot_frequency(obj, f, plot_type=None, **kwargs):
 
     plotit(ax2, obj, f, V, plot2_type, deltas, log_frequency=log_frequency,
            log_magnitude=log_magnitude, norm=norm, second=True, color=color2,
-           linestyle=linestyle2, **kwargs)
+           linestyle=linestyle2, unwrap=unwrap, **kwargs)
 
-    if plot2_type in ('phase', 'radians'):
+    if plot2_type in ('phase', 'radians') and not unwrap:
         ax2.set_ylim(-np.pi, np.pi)
-    elif plot2_type in ('phase-degrees', 'degrees'):
+    elif plot2_type in ('phase-degrees', 'degrees') and not unwrap:
         ax2.set_ylim(-180, 180)
 
     if plot1_type == 'dB':
@@ -449,12 +462,19 @@ def plot_frequency(obj, f, plot_type=None, **kwargs):
 
         ymin = np.floor(dBmin / 10) * 10
         ymax = np.ceil(dBmax / 10) * 10
+        yrange = ymax - ymin
+
+        if False:
+            # Provide some wiggle room
+            ymin -= yrange / 10
+            ymax += yrange / 10
+            yrange = ymax - ymin
+
         # This will clobber previous plot values
         ax.set_ylim(ymin, ymax)
 
-        yrange = ymax - ymin
         if nyticks is None:
-            # Add odd number is better to show zero phase.
+            # An odd number is better to show zero phase.
             for nyticks in (7, 6, 5, 8, 9):
                 if yrange / (nyticks - 1) in (20, 10, 5, 2):
                     break
@@ -475,6 +495,8 @@ def plot_bode(obj, f, **kwargs):
 
     if 'log_frequency' not in kwargs:
         kwargs['log_frequency'] = True
+    if 'unwrap' not in kwargs:
+        kwargs['unwrap'] = True
 
     return plot_frequency(obj, f, **kwargs)
 
@@ -491,6 +513,8 @@ def plot_angular_frequency(obj, omega, plot_type=None, **kwargs):
 
     npoints = kwargs.pop('npoints', 400)
     norm = kwargs.pop('norm', False)
+    log_frequency = kwargs.pop(
+        'log_frequency', False) or kwargs.pop('log_scale', False)
 
     # FIXME, determine useful frequency range...
     if omega is None:
@@ -501,14 +525,18 @@ def plot_angular_frequency(obj, omega, plot_type=None, **kwargs):
     if isinstance(omega, (int, float)):
         omega = (0, omega)
     if isinstance(omega, tuple):
-        wmin, wmax = parse_range(omega, 1e-1, positive=False)
-        omega = np.linspace(wmin, wmax, npoints)
+        if log_frequency:
+            wmin, wmax = parse_range(omega, 1e-1, positive=True)
+            omega = np.geomspace(wmin, wmax, npoints)
+        else:
+            wmin, wmax = parse_range(omega, 1e-1, positive=False)
+            omega = np.linspace(wmin, wmax, npoints)
 
     if norm and 'xlabel' not in kwargs:
         kwargs['xlabel'] = 'Normalized angular frequency'
 
     return plot_frequency(obj, omega, plot_type=plot_type,
-                          norm=norm, **kwargs)
+                          norm=norm, log_frequency=log_frequency, **kwargs)
 
 
 def plot_time(obj, t, plot_type=None, **kwargs):
@@ -542,7 +570,8 @@ def plot_time(obj, t, plot_type=None, **kwargs):
     elif plot_type == 'abs':
         v = abs(v)
     else:
-        raise ValueError('Invalid plot_type: must be real, imag, real-imag, abs')
+        raise ValueError(
+            'Invalid plot_type: must be real, imag, real-imag, abs')
 
     ax = make_axes(figsize=kwargs.pop('figsize', None),
                    axes=kwargs.pop('axes', None))
@@ -636,7 +665,8 @@ def plot_sequence(obj, ni, plot_type=None, polar=False, **kwargs):
     elif plot_type == 'abs':
         v = abs(v)
     else:
-        raise ValueError('Invalid plot_type: must be real, imag, real-imag, abs')
+        raise ValueError(
+            'Invalid plot_type: must be real, imag, real-imag, abs')
 
     deltas = None
     if obj.has(DiracDelta):
@@ -654,7 +684,8 @@ def plot_sequence(obj, ni, plot_type=None, polar=False, **kwargs):
     title = kwargs.pop('title', None)
     color = kwargs.pop('color', None)
 
-    markerline, stemlines, baseline = ax.stem(ni * xscale, v * yscale, use_line_collection=True, **kwargs)
+    markerline, stemlines, baseline = ax.stem(
+        ni * xscale, v * yscale, use_line_collection=True, **kwargs)
     if color is not None:
         stemlines.set_color(color)
         markerline.set_color(color)
@@ -738,7 +769,8 @@ def plot_nyquist(obj, f, norm=False, **kwargs):
                    axes=kwargs.pop('axes', None))
 
     if unitcircle:
-        ax.add_artist(Circle((0, 0), 1, color='blue', linestyle='--', fill=False))
+        ax.add_artist(Circle((0, 0), 1, color='blue',
+                      linestyle='--', fill=False))
 
     lines = ax.plot(V.real, V.imag)
 
